Method: PantographCore::Configuration#push_values!

Defined in:
pantograph_core/lib/pantograph_core/configuration/configuration.rb

#push_values!Object

Clears away any current configuration values by pushing them onto a stack. Values set after calling push_values! will be merged with the previous values after calling pop_values!

see: pop_values!



299
300
301
302
# File 'pantograph_core/lib/pantograph_core/configuration/configuration.rb', line 299

def push_values!
  @values_stack.push(@values)
  @values = {}
end